ToStringForNetwork

Trait ToStringForNetwork 

pub trait ToStringForNetwork {
    // Required method
    fn to_string(&self, network: Network) -> String;
}
Convert to String for a specified Bitcoin network type

Required Methods

fn to_string(&self, network: Network) -> String

Convert to String for a specified Bitcoin network type

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors